TubesClient class
Constructors
- TubesClient(TubesClientConfig config)
Properties
- config → TubesClientConfig
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
connect(
) → Future< void> -
dispose(
) → void -
handleError(
dynamic err) → void -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
registerHandler(
String channel, StreamController handler) → void -
send(
String channel, {dynamic payload = const <String, dynamic>{}, String type = RealtimeMessageTypes.realtimeMessageTypeChannelMessage}) → void -
subscribeChannel(
String channel) → Stream -
toString(
) → String -
A string representation of this object.
inherited
-
unregisterHandler(
String channel, StreamController handler) → void
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited